/**************************************************************************
TuXBuZZ - client bY DoC#include
client.h
**************************************************************************/

#ifndef CLIENT_H
#define CLIENT_H

#include <stdio.h>
#include <string.h>


#define VERSION "v0.0.2b"

#define CMDBUFF_LEN 1024 /* tamanho do buffer da linha de comando */

char cmdbuff[CMDBUFF_LEN]; /* buffer da linha de comando */

char *prompt = "tuxbuzz-"VERSION"> "; /* nosso prompt */

/* o banner */
char *banner = "\n\n************************************************************************" 
							 "\nTuXBuzz "VERSION" Client bY DoC#include\n"
				       "CopyRight 2001 All Rights Reserved\n"
               "This Software is Registered under the GNU Public Licence.\n"
							 "************************************************************************\n\n";

#endif 

/* fim de client.h */               
